function [x] = proximal_gradient(gradf, gamma, L, x0, k, max_iters)

% Minimizes regularization functional 
% f(w) + gamma/2 ||w||^2
% where ||.|| is the k-support norm
% uses proximal gradient method. 
% L                : Lipschitz constant for gradf
% x0               : initial value
% max_iters	   : maximum #iterations

alpha = x0;
x = x0;
theta = 1;
t = 1;
while (t < max_iters)
  gradalpha = feval(gradf,alpha);
  prevx = x;
  v = -1/L* gradalpha + alpha;
  x = prox_ksnorm(v, k, gamma/L);
  theta = (sqrt(theta^4+4*theta^2)-theta^2)/2;
  rho = 1-theta+sqrt(1-theta);
  alpha = rho*x - (rho-1)*prevx;
  t = t + 1;
end

